"""LabelOnlyOrder"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.modal_analysis.gears import _1857

_LABEL_ONLY_ORDER = python_net_import(
    "SMT.MastaAPI.Utility.ModalAnalysis.Gears", "LabelOnlyOrder"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="LabelOnlyOrder")
    CastSelf = TypeVar("CastSelf", bound="LabelOnlyOrder._Cast_LabelOnlyOrder")


__docformat__ = "restructuredtext en"
__all__ = ("LabelOnlyOrder",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LabelOnlyOrder:
    """Special nested class for casting LabelOnlyOrder to subclasses."""

    __parent__: "LabelOnlyOrder"

    @property
    def order_for_te(self: "CastSelf") -> "_1857.OrderForTE":
        return self.__parent__._cast(_1857.OrderForTE)

    @property
    def label_only_order(self: "CastSelf") -> "LabelOnlyOrder":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class LabelOnlyOrder(_1857.OrderForTE):
    """LabelOnlyOrder

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LABEL_ONLY_ORDER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_LabelOnlyOrder":
        """Cast to another type.

        Returns:
            _Cast_LabelOnlyOrder
        """
        return _Cast_LabelOnlyOrder(self)
