"""UserDefinedPropertyKey"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.databases import _1881

_USER_DEFINED_PROPERTY_KEY = python_net_import(
    "SMT.MastaAPI.Utility.Scripting", "UserDefinedPropertyKey"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="UserDefinedPropertyKey")
    CastSelf = TypeVar(
        "CastSelf", bound="UserDefinedPropertyKey._Cast_UserDefinedPropertyKey"
    )


__docformat__ = "restructuredtext en"
__all__ = ("UserDefinedPropertyKey",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_UserDefinedPropertyKey:
    """Special nested class for casting UserDefinedPropertyKey to subclasses."""

    __parent__: "UserDefinedPropertyKey"

    @property
    def database_key(self: "CastSelf") -> "_1881.DatabaseKey":
        return self.__parent__._cast(_1881.DatabaseKey)

    @property
    def user_defined_property_key(self: "CastSelf") -> "UserDefinedPropertyKey":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class UserDefinedPropertyKey(_1881.DatabaseKey):
    """UserDefinedPropertyKey

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _USER_DEFINED_PROPERTY_KEY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_UserDefinedPropertyKey":
        """Cast to another type.

        Returns:
            _Cast_UserDefinedPropertyKey
        """
        return _Cast_UserDefinedPropertyKey(self)
